# xDSL

TODO

## Formatting

All python code used in xDSL use yapf to format the code in a uniform manner. 

https://github.com/google/yapf

To automate the formatting within vim, one can use https://github.com/vim-autoformat/vim-autoformat and trigger a `:Autoformat` on save.
